# Generated by roxygen2: do not edit by hand

export(add_gerda_census)
export(add_gerda_covariates)
export(clear_gerda_cache)
export(gerda_cache_dir)
export(gerda_census)
export(gerda_census_codebook)
export(gerda_covariates)
export(gerda_covariates_codebook)
export(gerda_data_list)
export(load_gerda_web)
export(party_crosswalk)
import(dplyr)
import(readr)
import(stringdist)
