% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gerda_census.R
\name{gerda_census_codebook}
\alias{gerda_census_codebook}
\title{Get Codebook for Census 2022 Data}
\usage{
gerda_census_codebook()
}
\value{
A data frame with 16 rows documenting all variables in the census
dataset.
}
\description{
Returns the data dictionary for municipality-level Census 2022 indicators.
Provides variable names, labels, units, and data sources.
}
\examples{
# View the codebook
codebook <- gerda_census_codebook()
print(codebook)

}
\seealso{
\code{\link{gerda_census}} for the actual census data
}
